@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/glite/org.glite.lb.client/src/producer.c,v 1.87 2012/10/11 10:12:40 mvocu Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -40,7 +40,7 @@ limitations under the License.
 
 #define FCNTL_ATTEMPTS		5
 #define FCNTL_TIMEOUT		1
-#define DEFAULT_SOCKET "/tmp/interlogger.sock"
+#define DEFAULT_SOCKET		EDG_WLL_LOG_SOCKET_DEFAULT
 
 #ifdef FAKE_VERSION
 int edg_wll_DoLogEvent(edg_wll_Context ctx, edg_wll_LogLine logline);
@@ -921,8 +921,9 @@ static int edg_wll_RegisterJobMaster(
         edg_wlc_JobId **        subjobs,
 	char **			wms_dn)
 {
-	char	*seq,*type_s,*parent_s,*wms_dn_s;
+	char	*seq,*type_s,*parent_s,*wms_dn_s,*comparesrvname;
 	int	err = 0,i,seq_type;
+	unsigned int comparesrvport;
 	struct timeval sync_to;
 
 	seq = type_s = parent_s = wms_dn_s = NULL;
@@ -945,6 +946,15 @@ static int edg_wll_RegisterJobMaster(
 	}
 	memcpy(&sync_to, &ctx->p_sync_timeout, sizeof sync_to);
 
+	// Cancel proxy flag if both direct and proxy flags are specified and the target server is local to the proxy
+	if ((flags & EDG_WLL_LOGFLAG_PROXY) && ctx->p_lbproxy_servername && (flags & EDG_WLL_LOGFLAG_DIRECT)) {
+		glite_jobid_getServerParts(job, &comparesrvname, &comparesrvport);
+		if ((comparesrvport == ctx->p_lbproxy_servername_port) && (!strcmp(comparesrvname, ctx->p_lbproxy_servername))) {
+			flags = flags & (0 ^ EDG_WLL_LOGFLAG_PROXY);
+		}
+		free(comparesrvname);
+	}
+
 	if ( ((flags & (EDG_WLL_LOGFLAG_DIRECT | EDG_WLL_LOGFLAG_LOCAL)) == 
 				(EDG_WLL_LOGFLAG_DIRECT | EDG_WLL_LOGFLAG_LOCAL)) ||
 	     ((flags & (EDG_WLL_LOGFLAG_PROXY | EDG_WLL_LOGFLAG_LOCAL)) == 
